/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const epicsData = [
  { id: 0, title: 'Custom Field 1000', value: 'customfield_1000' },
  { id: 1, title: 'Custom Field 2000', value: 'customfield_2000' },
  { id: 2, title: 'Custom Field 3000', value: 'customfield_3000' },
  { id: 3, title: 'Custom Field 4000', value: 'customfield_4000' },
  { id: 4, title: 'Custom Field 5000', value: 'customfield_5000' }
]

export { epicsData }
